@@ -1,5 +1,4 @@
 from typing import Optional
-from opencv_stream import VideoStreamer, FpsDrawer
 import opencv_stream
 import numpy as np
 import torch
@@ -13,12 +12,12 @@ FILE = Path(__file__).resolve()
 ROOT = FILE.parents[0]  # yolov5 strongsort root directory
 WEIGHTS = ROOT / 'weights'
 
-if str(ROOT) not in sys.path:
-    sys.path.append(str(ROOT))  # add ROOT to PATH
-if str(ROOT / 'yolov5') not in sys.path:
-    sys.path.append(str(ROOT / 'yolov5'))  # add yolov5 ROOT to PATH
-if str(ROOT / 'trackers' / 'strong_sort') not in sys.path:
-    sys.path.append(str(ROOT / 'trackers' / 'strong_sort'))  # add strong_sort ROOT to PATH
+# if str(ROOT) not in sys.path:
+#     sys.path.append(str(ROOT))  # add ROOT to PATH
+# if str(ROOT / 'yolov5') not in sys.path:
+#     sys.path.append(str(ROOT / 'yolov5'))  # add yolov5 ROOT to PATH
+# if str(ROOT / 'trackers' / 'strong_sort') not in sys.path:
+#     sys.path.append(str(ROOT / 'trackers' / 'strong_sort'))  # add strong_sort ROOT to PATH
 
 ROOT = Path(os.path.relpath(ROOT, Path.cwd()))  # relative
 
@@ -28,7 +27,7 @@ from .yolov5.utils.general import non_max_suppression, scale_boxes
 from .yolov5.utils.torch_utils import select_device
 from .yolov5.utils.dataloaders import letterbox
 from .yolov5.utils.general import check_img_size
-from trackers.multi_tracker_zoo import create_tracker
+from .trackers.multi_tracker_zoo import create_tracker
 import cv2
 
 class PersonCounterModel(opencv_stream.Model):
